# -*- coding: UTF-8 -*-
from flask import Blueprint, current_app, session, json, request
from xmlrpclib import ServerProxy
from flask.views import MethodView
from eop.modules.api import membersapi, ldapusersapi
from eoleauthlib.authclient import login_required
from eop import utils
import sys
sys.path.append('/usr/share')
from ead2.backend.actions.scribe.tool.etablissements import get_etabs

etabsapi = Blueprint('etabsapi', __name__, url_prefix='/api/etabs/')

class EtabsAPI(MethodView):
    decorators = [login_required]

    def __init__(self):
        self.username = session["username"]
        self.proxy = ServerProxy(current_app.config['CONTROLEVNC_URL'])
        self.secret = current_app.config['SECRET_KEY']

    def get(self):
        """Returns a list of etabs of the user
        """
        etabslist = []
        etabslist = get_etabs()
        if len(etabslist) > 1:
            etb = []
            etb.append(etabslist[0])
            for e in etabslist[1]:
                etb.append(e)
            etabslist = etb
        if utils.est_admin():
            return json.dumps(etabslist)

        groups = self.proxy.remote_user_groupes(self.username)
        etb = []
        for etab in etabslist :
            for group in groups:
                if etab in group:
                    if etab not in etb :
                        etb.append(etab)
        return json.dumps(etb)

    def post(self):
        """Returns a list of members of etabs
        """
        response = request.form
        etbs = json.loads(response["etabs"])
        if current_app.config['MULTI_ETAB'] == "oui":
            etabslist = self.proxy.remote_etabs_eleves(etbs)
        else:
            etabslist = self.proxy.remote_etabs_eleves(etbs[0])
        return json.dumps(etabslist)

    def delete(self):
        raise NotImplementedError

    def put(self):
        raise NotImplementedError

    @classmethod
    def register(cls, mod):
        f = cls.as_view("etabs_api")
        mod.add_url_rule('', view_func=f, methods=["GET", "POST"])


EtabsAPI.register(etabsapi)
